==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/search/kotlin/inputs/PrivateEndpointConnectionPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.search.kotlin.inputs

import com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesArgs.builder
import com.pulumi.azurenative.search.kotlin.enums.PrivateLinkServiceConnectionProvisioningState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes the properties of an existing Private Endpoint connection to the Azure Cognitive Search service.
 * @property groupId The group id from the provider of resource the private link service connection is for.
 * @property privateEndpoint The private endpoint resource from Microsoft.Network provider.
 * @property privateLinkServiceConnectionState Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
 * @property provisioningState The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
 */
public data class PrivateEndpointConnectionPropertiesArgs(
    public val groupId: Output<String>? = null,
    public val privateEndpoint: Output<PrivateEndpointConnectionPropertiesPrivateEndpointArgs>? =
        null,
    public val privateLinkServiceConnectionState:
    Output<PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs>? = null,
    public val provisioningState:
    Output<Either<String, PrivateLinkServiceConnectionProvisioningState>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesArgs =
        com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesArgs.builder()
            .groupId(groupId?.applyValue({ args0 -> args0 }))
            .privateEndpoint(privateEndpoint?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .privateLinkServiceConnectionState(
                privateLinkServiceConnectionState?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .provisioningState(
                provisioningState?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [PrivateEndpointConnectionPropertiesArgs].
 */
@PulumiTagMarker
public class PrivateEndpointConnectionPropertiesArgsBuilder internal constructor() {
    private var groupId: Output<String>? = null

    private var privateEndpoint: Output<PrivateEndpointConnectionPropertiesPrivateEndpointArgs>? =
        null

    private var privateLinkServiceConnectionState:
        Output<PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs>? = null

    private var provisioningState:
        Output<Either<String, PrivateLinkServiceConnectionProvisioningState>>? = null

    /**
     * @param value The group id from the provider of resource the private link service connection is for.
     */
    @JvmName("chhdfmooliftmoiy")
    public suspend fun groupId(`value`: Output<String>) {
        this.groupId = value
    }

    /**
     * @param value The private endpoint resource from Microsoft.Network provider.
     */
    @JvmName("lfrgrrqdpoyrferg")
    public suspend
    fun privateEndpoint(`value`: Output<PrivateEndpointConnectionPropertiesPrivateEndpointArgs>) {
        this.privateEndpoint = value
    }

    /**
     * @param value Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
     */
    @JvmName("ymgimbewdunjjdja")
    public suspend
    fun privateLinkServiceConnectionState(`value`: Output<PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs>) {
        this.privateLinkServiceConnectionState = value
    }

    /**
     * @param value The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
     */
    @JvmName("vvkrgfgxiqefdgoa")
    public suspend
    fun provisioningState(`value`: Output<Either<String, PrivateLinkServiceConnectionProvisioningState>>) {
        this.provisioningState = value
    }

    /**
     * @param value The group id from the provider of resource the private link service connection is for.
     */
    @JvmName("gbyrdicfqkqwwyie")
    public suspend fun groupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupId = mapped
    }

    /**
     * @param value The private endpoint resource from Microsoft.Network provider.
     */
    @JvmName("fjufotnmewsthuif")
    public suspend
    fun privateEndpoint(`value`: PrivateEndpointConnectionPropertiesPrivateEndpointArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateEndpoint = mapped
    }

    /**
     * @param argument The private endpoint resource from Microsoft.Network provider.
     */
    @JvmName("nahkdhxemapkilhf")
    public suspend
    fun privateEndpoint(argument: suspend PrivateEndpointConnectionPropertiesPrivateEndpointArgsBuilder.() -> Unit) {
        val toBeMapped = PrivateEndpointConnectionPropertiesPrivateEndpointArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.privateEndpoint = mapped
    }

    /**
     * @param value Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
     */
    @JvmName("xrcdusaditcolebi")
    public suspend
    fun privateLinkServiceConnectionState(`value`: PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkServiceConnectionState = mapped
    }

    /**
     * @param argument Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
     */
    @JvmName("uhecttgcewqxsdev")
    public suspend
    fun privateLinkServiceConnectionState(argument: suspend PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder.() -> Unit) {
        val toBeMapped =
            PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.privateLinkServiceConnectionState = mapped
    }

    /**
     * @param value The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
     */
    @JvmName("kbffeagweyobahoe")
    public suspend
    fun provisioningState(`value`: Either<String, PrivateLinkServiceConnectionProvisioningState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
     */
    @JvmName("jvpopfhwugnxkdfs")
    public fun provisioningState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PrivateLinkServiceConnectionProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
     */
    @JvmName("bgrnyvisnfoqgdoh")
    public fun provisioningState(`value`: PrivateLinkServiceConnectionProvisioningState) {
        val toBeMapped = Either.ofRight<String, PrivateLinkServiceConnectionProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    internal fun build(): PrivateEndpointConnectionPropertiesArgs =
        PrivateEndpointConnectionPropertiesArgs(
            groupId = groupId,
            privateEndpoint = privateEndpoint,
            privateLinkServiceConnectionState = privateLinkServiceConnectionState,
            provisioningState = provisioningState,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/search/kotlin/inputs/PrivateEndpointConnectionPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.search.kotlin.inputs

import com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesArgs.builder
import com.pulumi.azurenative.search.kotlin.enums.PrivateLinkServiceConnectionProvisioningState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes the properties of an existing Private Endpoint connection to the Azure Cognitive Search service.
 * @property groupId The group id from the provider of resource the private link service connection is for.
 * @property privateEndpoint The private endpoint resource from Microsoft.Network provider.
 * @property privateLinkServiceConnectionState Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
 * @property provisioningState The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
 */
public data class PrivateEndpointConnectionPropertiesArgs(
    public val groupId: Output<String>? = null,
    public val privateEndpoint: Output<PrivateEndpointConnectionPropertiesPrivateEndpointArgs>? =
        null,
    public val privateLinkServiceConnectionState:
    Output<PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs>? = null,
    public val provisioningState:
    Output<Either<String, PrivateLinkServiceConnectionProvisioningState>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesArgs =
        com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesArgs.builder()
            .groupId(groupId?.applyValue({ args0 -> args0 }))
            .privateEndpoint(privateEndpoint?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .privateLinkServiceConnectionState(
                privateLinkServiceConnectionState?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .provisioningState(
                provisioningState?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [PrivateEndpointConnectionPropertiesArgs].
 */
@PulumiTagMarker
public class PrivateEndpointConnectionPropertiesArgsBuilder internal constructor() {
    private var groupId: Output<String>? = null

    private var privateEndpoint: Output<PrivateEndpointConnectionPropertiesPrivateEndpointArgs>? =
        null

    private var privateLinkServiceConnectionState:
        Output<PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs>? = null

    private var provisioningState:
        Output<Either<String, PrivateLinkServiceConnectionProvisioningState>>? = null

    /**
     * @param value The group id from the provider of resource the private link service connection is for.
     */
    @JvmName("tjjirlpiquhlsouy")
    public suspend fun groupId(`value`: Output<String>) {
        this.groupId = value
    }

    /**
     * @param value The private endpoint resource from Microsoft.Network provider.
     */
    @JvmName("ijwkyawjpxjampgq")
    public suspend
    fun privateEndpoint(`value`: Output<PrivateEndpointConnectionPropertiesPrivateEndpointArgs>) {
        this.privateEndpoint = value
    }

    /**
     * @param value Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
     */
    @JvmName("ujeagmcktbigadvt")
    public suspend
    fun privateLinkServiceConnectionState(`value`: Output<PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs>) {
        this.privateLinkServiceConnectionState = value
    }

    /**
     * @param value The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
     */
    @JvmName("jgfocpywrgnuwhfj")
    public suspend
    fun provisioningState(`value`: Output<Either<String, PrivateLinkServiceConnectionProvisioningState>>) {
        this.provisioningState = value
    }

    /**
     * @param value The group id from the provider of resource the private link service connection is for.
     */
    @JvmName("isirafglyonmkyff")
    public suspend fun groupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupId = mapped
    }

    /**
     * @param value The private endpoint resource from Microsoft.Network provider.
     */
    @JvmName("boqpmwhxlanhvyau")
    public suspend
    fun privateEndpoint(`value`: PrivateEndpointConnectionPropertiesPrivateEndpointArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateEndpoint = mapped
    }

    /**
     * @param argument The private endpoint resource from Microsoft.Network provider.
     */
    @JvmName("uyjdssrokdufkhkb")
    public suspend
    fun privateEndpoint(argument: suspend PrivateEndpointConnectionPropertiesPrivateEndpointArgsBuilder.() -> Unit) {
        val toBeMapped = PrivateEndpointConnectionPropertiesPrivateEndpointArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.privateEndpoint = mapped
    }

    /**
     * @param value Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
     */
    @JvmName("tcprnejhajqmgemd")
    public suspend
    fun privateLinkServiceConnectionState(`value`: PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkServiceConnectionState = mapped
    }

    /**
     * @param argument Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
     */
    @JvmName("phcbwjqsmqsvxckx")
    public suspend
    fun privateLinkServiceConnectionState(argument: suspend PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder.() -> Unit) {
        val toBeMapped =
            PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.privateLinkServiceConnectionState = mapped
    }

    /**
     * @param value The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
     */
    @JvmName("ftyvcjyugocwgxdv")
    public suspend
    fun provisioningState(`value`: Either<String, PrivateLinkServiceConnectionProvisioningState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
     */
    @JvmName("qlaclvjdtcgsetdg")
    public fun provisioningState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PrivateLinkServiceConnectionProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioning state of the private link service connection. Can be Updating, Deleting, Failed, Succeeded, or Incomplete
     */
    @JvmName("pkjtauduoftylfuu")
    public fun provisioningState(`value`: PrivateLinkServiceConnectionProvisioningState) {
        val toBeMapped = Either.ofRight<String, PrivateLinkServiceConnectionProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    internal fun build(): PrivateEndpointConnectionPropertiesArgs =
        PrivateEndpointConnectionPropertiesArgs(
            groupId = groupId,
            privateEndpoint = privateEndpoint,
            privateLinkServiceConnectionState = privateLinkServiceConnectionState,
            provisioningState = provisioningState,
        )
}
